# Silmused

# Current versions
* python @3.10
* psycopg2 @2.9.9

# Code reference
## Basics
* private methods are noted with an underscore (`_`) at the start 

## Test Structure
### TestDefinition
This is the heart and soul of `Silmused` and defines how tests should behave.

:note: Some classes do not implicitly use this as they serve a different purpose.
* ExecuteLayer
* TitleLayer
* ChecksLayer

### ConstraintTest
### DataTest
### FunctionTest
### IndexText
### ProcedureTest
### StructureTest
### TriggerTest
### ViewTest

### ChecksLayer
### ExecuteLayer
### TitleLayer

## Runner